@@ -168,7 +168,8 @@ GfLogicalMonitor           *gf_monitor_manager_get_primary_logical_monitor  (GfM
 
 gboolean                    gf_monitor_manager_has_hotplug_mode_update      (GfMonitorManager            *manager);
 void                        gf_monitor_manager_read_current_state           (GfMonitorManager            *manager);
-void                        gf_monitor_manager_on_hotplug                   (GfMonitorManager            *manager);
+
+void                        gf_monitor_manager_reconfigure                  (GfMonitorManager            *self);
 
 gboolean                    gf_monitor_manager_get_monitor_matrix           (GfMonitorManager            *manager,
                                                                              GfMonitor                   *monitor,
