@@ -228,12 +228,18 @@ settings_changed (GSettings   *settings,
 
 #undef SETTING_CHANGED
 
+  if (application->desktop)
+    gf_desktop_set_monitor_manager (application->desktop, monitor_manager);
+
   if (application->input_settings)
     gf_input_settings_set_monitor_manager (application->input_settings,
                                            monitor_manager);
 
   if (application->screensaver)
     {
+      gf_screensaver_set_monitor_manager (application->screensaver,
+                                          monitor_manager);
+
       gf_screensaver_set_input_sources (application->screensaver,
                                         application->input_sources);
     }
